@@ -3,7 +3,7 @@ package Ryu::Node;
 use strict;
 use warnings;
 
-our $VERSION = '0.030'; # VERSION
+our $VERSION = '0.031'; # VERSION
 
 =head1 NAME
 
@@ -22,7 +22,12 @@ Not really. There's a constructor, but that's not particularly exciting.
 
 =cut
 
-sub new { bless { @_[1..$#_] }, $_[0] }
+sub new {
+    bless {
+        pause_propagation => 1,
+        @_[1..$#_]
+    }, $_[0]
+}
 
 =head2 pause
 
@@ -38,9 +43,9 @@ sub pause {
     my $was_paused = keys %{$self->{is_paused}};
     ++$self->{is_paused}{$k};
     if(my $parent = $self->parent) {
-        $parent->pause($self);
+        $parent->pause($self) if $self->{pause_propagation};
     }
-    if(my $flow_control = $self->{pause_source}) {
+    if(my $flow_control = $self->{flow_control}) {
         $flow_control->emit(0) unless $was_paused;
     }
     $self
@@ -59,9 +64,9 @@ sub resume {
     delete $self->{is_paused}{$k} unless --$self->{is_paused}{$k} > 0;
     unless(keys %{$self->{is_paused} || {} }) {
         if(my $parent = $self->parent) {
-            $parent->resume($self);
+            $parent->resume($self) if $self->{pause_propagation};
         }
-        if(my $flow_control = $self->{pause_source}) {
+        if(my $flow_control = $self->{flow_control}) {
             $flow_control->emit(1);
         }
     }
