@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Ryu::Node);
 
-our $VERSION = '0.030'; # VERSION
+our $VERSION = '0.031'; # VERSION
 
 =head1 NAME
 
@@ -683,6 +683,38 @@ sub sprintf_methods {
     }, $src);
 }
 
+sub buffer {
+    my ($self, $count) = @_;
+    my $src = $self->chained(label => (caller 0)[3] =~ /::([^:]+)$/);
+    $src->{pause_propagation} = 0;
+    $count ||= 10;
+    my @pending;
+    $self->completed->on_ready(sub {
+        shift->on_ready($src->completed) unless $src->completed->is_ready
+    });
+    $src->flow_control
+        ->each($src->$curry::weak(sub {
+            my ($src) = @_;
+            return unless $_;
+            $src->emit(shift @pending) while @pending and not $src->is_paused;
+        }))->retain;
+    $self->each_while_source($self->$curry::weak(sub {
+        my ($self, $item) = @_;
+        push @pending, $item;
+        $self->pause($src) if @pending >= $count;
+        $src->emit(shift @pending) while @pending and not $src->is_paused;
+        $self->resume($src) if @pending < $count;
+    }), $src);
+}
+
+sub retain {
+    my ($self) = @_;
+    $self->{_self} = $self;
+    $self->completed
+        ->on_ready(sub { delete $self->{_self} });
+    $self
+}
+
 =head2 as_list
 
 Resolves to a list consisting of all items emitted by this source.
@@ -1796,7 +1828,7 @@ sub each_while_source {
     $self->each($code);
     $src->completed->on_ready(sub {
         my $count = extract_by { refaddr($_) == refaddr($code) } @{$self->{on_item}};
-        $log->tracef("->e_w_s completed on %s for refaddr 0x%x", $self->describe, refaddr($self));
+        $log->tracef("->each_while_source completed on %s for refaddr 0x%x, removed %d on_item handlers", $self->describe, refaddr($self), $count);
     });
     $src
 }
